@@ -372,23 +372,19 @@ def get_predictions(
     if isinstance(price_areas, str):
         price_areas = [price_areas]
 
-    if start is None:
-        start = archimedes.constants.DATE_LOW
-    else:
-        start = pd.to_datetime(start)
+    query = {}
 
-    if end is None:
-        end = archimedes.constants.DATE_HIGH
-    else:
-        end = pd.to_datetime(end)
+    if start is not None:
+        query["start"] = pd.to_datetime(start, utc=True)
 
-    query = {"start": start, "end": end}
+    if end is not None:
+        query["end"] = pd.to_datetime(end, utc=True)
 
     if ref_dt_start is not None:
-        query["ref_dt_start"] = pd.to_datetime(ref_dt_start)
+        query["ref_dt_start"] = pd.to_datetime(ref_dt_start, utc=True)
 
     if ref_dt_end is not None:
-        query["ref_dt_end"] = pd.to_datetime(ref_dt_end)
+        query["ref_dt_end"] = pd.to_datetime(ref_dt_end, utc=True)
 
     if series_ids is not None:
         query["series_ids"] = series_ids
@@ -409,9 +405,13 @@ def get_predictions(
 
     df = pd.DataFrame.from_dict(data)
 
-    df["from_dt"] = pd.to_datetime(df["from_dt"], utc=True)
-    df["run_dt"] = pd.to_datetime(df["run_dt"], utc=True)
-    df["ref_dt"] = pd.to_datetime(df["ref_dt"], utc=True)
+    date_fields = ["from_dt", "run_dt", "ref_dt"]
+
+    for date_field in date_fields:
+        if date_field in df:
+            df[date_field] = pd.to_datetime(df[date_field], utc=True)
+
+    df = df.fillna("")
 
     return df
 
@@ -719,7 +719,7 @@ def forecast_diff(
     assert comparison_type in [
         "forecast_update",
         "forecast_diff",
-    ], f"Unknown comparison_type '{comparison_type}' (should be either 'forecast_update' or 'forecast_diff'"
+    ], f"Unknown comparison_type '{comparison_type}' (should be either 'forecast_update' or 'forecast_diff')"
     query = {
         "forecast_comparison_type": comparison_type,
         "series_ids": series_ids,
